import { useState } from "react";
import { PublicUser } from "../Types/goTypes";
import UserInfoModal from "./UserInfoModal";

/**
 * The props for the UserProps component
 */
interface UserProps {
  users: PublicUser[];
}

/**
 * A list of users for admin manage users page, that sets an onClick
 * function for eact user <li> element, which displays a modul with
 * user info.
 * @param props - An array of users users to display
 * @returns {JSX.Element} The user list
 * @example
 * const users = [{ id: 1, userName: "ExampleName" }];
 * return <UserList users={users} />;
 */

export function UserListAdmin(props: UserProps): JSX.Element {
  const [modalVisible, setModalVisible] = useState(false);
  const [username, setUsername] = useState("");

  const handleClick = (username: string): void => {
    setUsername(username);
    setModalVisible(true);
  };

  const handleClose = (): void => {
    setUsername("");
    setModalVisible(false);
  };

  return (
    <>
      <UserInfoModal
        onClose={handleClose}
        isVisible={modalVisible}
        username={username}
      />
      <div>
        <ul className="font-bold underline text-[30px] cursor-pointer padding">
          {props.users.map((user) => (
            <li
              className="pt-5"
              key={user.userId}
              onClick={() => {
                handleClick(user.username);
              }}
            >
              {user.username}
            </li>
          ))}
        </ul>
      </div>
    </>
  );
}
